"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.help = exports.commandNames = exports.cliOptionsTypes = exports.rcOptionsTypes = void 0;
const cli_utils_1 = require("@pnpm/cli-utils");
const error_1 = require("@pnpm/error");
const render_help_1 = __importDefault(require("render-help"));
const configGet_1 = require("./configGet");
const configSet_1 = require("./configSet");
const configList_1 = require("./configList");
function rcOptionsTypes() {
    return {};
}
exports.rcOptionsTypes = rcOptionsTypes;
function cliOptionsTypes() {
    return {
        global: Boolean,
        location: ['global', 'project'],
        json: Boolean,
    };
}
exports.cliOptionsTypes = cliOptionsTypes;
exports.commandNames = ['config', 'c'];
function help() {
    return (0, render_help_1.default)({
        description: 'Manage the pnpm configuration files.',
        descriptionLists: [
            {
                title: 'Commands',
                list: [
                    {
                        description: 'Set the config key to the value provided',
                        name: 'set',
                    },
                    {
                        description: 'Print the config value for the provided key',
                        name: 'get',
                    },
                    {
                        description: 'Remove the config key from the config file',
                        name: 'delete',
                    },
                    {
                        description: 'Show all the config settings',
                        name: 'list',
                    },
                ],
            },
            {
                title: 'Options',
                list: [
                    {
                        description: 'Sets the configuration in the global config file',
                        name: '--global',
                        shortAlias: '-g',
                    },
                    {
                        description: 'When set to "project", the .npmrc file at the nearest package.json will be used',
                        name: '--location <project|global>',
                    },
                    {
                        description: 'Show all the config settings in JSON format',
                        name: '--json',
                    },
                ],
            },
        ],
        url: (0, cli_utils_1.docsUrl)('config'),
        usages: [
            'pnpm config set <key> <value>',
            'pnpm config get <key>',
            'pnpm config delete <key>',
            'pnpm config list',
            'pnpm config list --json',
        ],
    });
}
exports.help = help;
async function handler(opts, params) {
    if (params.length === 0) {
        throw new error_1.PnpmError('CONFIG_NO_SUBCOMMAND', 'Please specify the subcommand', {
            hint: help(),
        });
    }
    if (opts.location) {
        opts.global = opts.location === 'global';
    }
    else if (opts.cliOptions['global'] == null) {
        opts.global = true;
    }
    switch (params[0]) {
        case 'set':
        case 'delete': {
            if (!params[1]) {
                throw new error_1.PnpmError('CONFIG_NO_PARAMS', `\`pnpm config ${params[0]}\` requires the config key`);
            }
            if (params[0] === 'set') {
                let [key, value] = params.slice(1);
                if (value == null) {
                    const parts = key.split('=');
                    key = parts.shift();
                    value = parts.join('=');
                }
                return (0, configSet_1.configSet)(opts, key, value ?? '');
            }
            else {
                return (0, configSet_1.configSet)(opts, params[1], null);
            }
        }
        case 'get': {
            if (params[1]) {
                return (0, configGet_1.configGet)(opts, params[1]);
            }
            else {
                return (0, configList_1.configList)(opts);
            }
        }
        case 'list': {
            return (0, configList_1.configList)(opts);
        }
        default: {
            throw new error_1.PnpmError('CONFIG_UNKNOWN_SUBCOMMAND', 'This subcommand is not known');
        }
    }
}
exports.handler = handler;
//# sourceMappingURL=config.js.map